@@ -11,7 +11,7 @@ use Cwd;
 
 use vars qw($VERSION);
 
-$VERSION = '1.6.6';
+$VERSION = '1.6.8';
 
 sub new {
   my $class = shift;
@@ -35,7 +35,7 @@ sub new {
 
 sub _initialize {
   my $self = shift;
-  
+
   if (!defined($self->{'Server'})) {
     croak "$self->{'CLASS'} not initialized properly : Server parameter missing";
   }
@@ -74,11 +74,11 @@ sub _initialize {
 	    }
     }
     my $SSL_try = "use IO::Socket::SSL";
-    
+
     eval $SSL_try;
 #	$IO::Socket::SSL::DEBUG = 1;
     if (!eval {
-	    $self->{'Socket'} = 
+	    $self->{'Socket'} =
       IO::Socket::SSL->new(PeerAddr => $self->{'Server'},
                            PeerPort => $self->{'Port'},
                            Proto => 'tcp',
@@ -93,7 +93,7 @@ sub _initialize {
   } else {
     if ($self->{'Server'} =~ /^\//) {
         if (!eval {
-            $self->{'Socket'} = 
+            $self->{'Socket'} =
         IO::Socket::UNIX->new(Peer => $self->{'Server'}); })
         {
             delete $self->{'Socket'};
@@ -103,7 +103,7 @@ sub _initialize {
         }
       } else {
           if (!eval {
-              $self->{'Socket'} = 
+              $self->{'Socket'} =
           IO::Socket::INET->new(PeerAddr => $self->{'Server'},
                                   PeerPort => $self->{'Port'},
                                   Proto => 'tcp',
@@ -191,7 +191,7 @@ sub _error {
   my $self = shift;
   my $func = shift;
   my @error = @_;
-  
+
   $self->{'Error'} = join(" ",$self->{'CLASS'}, "[", $func, "]:", @error);
   return;
 }
@@ -231,7 +231,7 @@ sub _read {
 
 sub close {
   my $self = shift;
-  
+
   if (!defined($self->{'Socket'})) {
     return 0;
   }
@@ -245,7 +245,7 @@ sub close {
 
 sub create {
   my $self = shift;
-  
+
   if (!defined($self->{'Socket'})) {
     return 1;
   }
@@ -272,21 +272,26 @@ sub create {
 
 sub rename {
   my $self = shift;
-  
+
   if (!defined($self->{'Socket'})) {
     return 1;
   }
-  if (scalar(@_) != 2) {
+  if ((scalar(@_) != 2) && (scalar(@_) != 3)) {
     $self->_error("rename", "incorrect number of arguments");
     return 1;
   }
   my $old_name = shift;
   my $new_name = shift;
-  
+  my $partition = shift;
+
   my $fh = $self->{'Socket'};
-  print $fh qq{try RENAME "$old_name" "$new_name"\n};
+  if (defined $partition) {
+    print $fh qq{try RENAME "$old_name" "$new_name" $partition\n};
+  } else {
+    print $fh qq{try RENAME "$old_name" "$new_name"\n};
+  }
   my $try = $self->_read;
-  if ($try =~ /^try OK/) {
+  if (($try =~ /^try OK/) || ($try =~ /^\* OK/)) {
     $self->{'Error'} = 'No Errors';
     return 0;
   } else {
@@ -298,7 +303,7 @@ sub rename {
 
 sub delete {
   my $self = shift;
-  
+
   if (!defined($self->{'Socket'})) {
     return 1;
   }
@@ -321,7 +326,7 @@ sub delete {
 
 sub h_delete {
   my $self = shift;
-  
+
   if (!defined($self->{'Socket'})) {
     return 1;
   }
@@ -344,7 +349,7 @@ sub h_delete {
     if ($try =~ /^try OK/) {
       $self->{'Error'} = 'No Errors';
     } else {
-       $self->_error("h_delete", "couldn't delete", 
+       $self->_error("h_delete", "couldn't delete",
                      $mailbox, ":", $try);
        return 1; # or just return on the first encountered error ?
     }
@@ -355,7 +360,7 @@ sub h_delete {
 sub get_quotaroot { # returns an array or undef
   my $self = shift;
   my (@quota, @info);
-  
+
   if (!defined($self->{'Socket'})) {
     return 1;
   }
@@ -389,12 +394,12 @@ sub get_quotaroot { # returns an array or undef
 sub get_quota { # returns an array or undef
   my $self = shift;
   my (@quota, @info);
-  
+
   if (!defined($self->{'Socket'})) {
     return;
   }
   if (!($self->{'Capability'} =~ /QUOTA/)) {
-    $self->_error("get_quota", 
+    $self->_error("get_quota",
                   "QUOTA not listed in server's capabilities");
     return;
   }
@@ -421,7 +426,7 @@ sub get_quota { # returns an array or undef
 
 sub set_quota {
   my $self = shift;
-  
+
   if (!defined($self->{'Socket'})) {
     return 1;
   }
@@ -453,7 +458,7 @@ sub set_quota {
 
 sub subscribe {
   my $self = shift;
-  
+
   if (!defined($self->{'Socket'})) {
     return 1;
   }
@@ -476,7 +481,7 @@ sub subscribe {
 
 sub unsubscribe {
   my $self = shift;
-  
+
   if (!defined($self->{'Socket'})) {
     return 1;
   }
@@ -555,7 +560,7 @@ sub expunge { # returns an array or undef
 
 sub get_acl { # returns an array or undef
   my $self = shift;
-  
+
   if (!defined($self->{'Socket'})) {
     return;
   }
@@ -589,7 +594,7 @@ sub get_acl { # returns an array or undef
 sub set_acl {
   my $self = shift;
   my ($id, $acl);
-  
+
   if (!defined($self->{'Socket'})) {
     return 1;
   }
@@ -613,7 +618,7 @@ sub set_acl {
     print $fh qq{try SETACL "$mailbox" "$id" "$acl"\n};
     my $try = $self->_read;
     if ($try !~ /^try OK/) {
-      $self->_error("set_acl", "couldn't set acl for", $mailbox, $id, 
+      $self->_error("set_acl", "couldn't set acl for", $mailbox, $id,
                     $acl, ":", $try);
       return 1;
     }
@@ -625,7 +630,7 @@ sub set_acl {
 sub delete_acl {
   my $self = shift;
   my ($id, $acl);
-  
+
   if (!defined($self->{'Socket'})) {
     return 1;
   }
@@ -655,7 +660,7 @@ sub delete_acl {
 sub list { # wild cards are allowed, returns array or undef
   my $self = shift;
   my (@info, @mail);
-  
+
   if (!defined($self->{'Socket'})) {
     return;
   }
@@ -692,7 +697,7 @@ IMAP::Admin - Perl module for basic IMAP server administration
 =head1 SYNOPSIS
 
   use IMAP::Admin;
-    
+
   $imap = IMAP::Admin->new('Server' => 'name.of.server.com',
                            'Login' => 'login_of_imap_administrator',
                            'Password' => 'password_of_imap_adminstrator',
@@ -710,7 +715,7 @@ IMAP::Admin - Perl module for basic IMAP server administration
   if ($err != 0) {
     print $imap->error;
   }
-  $err = $imap->create("user.bob", "green"); 
+  $err = $imap->create("user.bob", "green");
   $err = $imap->delete("user.bob");
   $err = $imap->h_delete("user.bob");
 
@@ -718,6 +723,7 @@ IMAP::Admin - Perl module for basic IMAP server administration
   $err = $imap->unsubscribe("user.bob");
 
   $err = $imap->rename("bboard", "newbboard");
+  $err = $imap->rename("bboard", "newbboard", "partition");
 
   @quota = $imap->get_quotaroot("user.bob");
   @quota = $imap->get_quota("user.bob");
@@ -727,7 +733,7 @@ IMAP::Admin - Perl module for basic IMAP server administration
   %acl = $imap->get_acl("user.bob");
   $err = $imap->set_acl("user.bob", "admin", "lrswipdca", "joe", "lrs");
   $err = $imap->delete_acl("user.bob", "joe", "admin");
- 
+
   @list = $imap->list("user.bob");
   @list = $imap->list("user.b*");
 
@@ -791,17 +797,17 @@ list lists mailboxes.  list accepts wildcard matching
 
 subscribe/unsubscribe does this action on given mailbox.
 
-rename renames a mailbox.  IMAP servers seem to be peculiar about how they implement this, so I wouldn't necessarily expect it to do what you think it should.
+rename renames a mailbox.  IMAP servers seem to be peculiar about how they implement this, so I wouldn't necessarily expect it to do what you think it should. The Cyrus IMAP server will move a renamed mailbox to the default partition unless a partition is given. You can optionally supply a partition name as an extra argument to this function.
 
 select selects a mailbox to work on. You need the 'r' acl to select a mailbox.
 This command selects a mailbox that mailbox related commands will be performed on.  This is not a recursive command so sub-mailboxes/folders will not be affected unless for some bizarre reason the IMAP server has it implemented as recursive.  It returns an error or an array that contains information about the mailbox.  For example:
 FLAGS (\Answered \Flagged \Draft \Deleted \Seen $Forwarded $MDNSent NonJunk Junk $Label7)
-OK [PERMANENTFLAGS (\Deleted)]  
+OK [PERMANENTFLAGS (\Deleted)]
 2285 EXISTS
 2285 RECENT
-OK [UNSEEN 1]  
-OK [UIDVALIDITY 1019141395]  
-OK [UIDNEXT 293665]  
+OK [UNSEEN 1]
+OK [UIDVALIDITY 1019141395]
+OK [UIDNEXT 293665]
 OK [READ-WRITE] Completed
 
 expunge permanently removes messages flagged with \Deleted out of the current selected mailbox.
@@ -817,7 +823,7 @@ It returns a list of message sequence numbers that it deleted.  You need to sele
 
 RFC2087 imap extensions.  These are supported by Cyrus IMAP and Mirapoint.
 
-get_quotaroot and get_quota retrieve quota information.  They return an array on success and undef on failure.  In the event of a failure the error is place in the object->{'Error'} variable.  The array has three elements for each item in the quota. 
+get_quotaroot and get_quota retrieve quota information.  They return an array on success and undef on failure.  In the event of a failure the error is place in the object->{'Error'} variable.  The array has three elements for each item in the quota.
 $quota[0] <- mailbox name
 $quota[1] <- quota amount used in kbytes
 $quota[2] <- quota in kbytes
@@ -869,10 +875,6 @@ Currently all the of the socket traffic is handled via prints and _read.  This m
 
 This is licensed under the Artistic license (same as perl).  A copy of the license is included in this package.  The file is called Artistic.  If you use this in a product or distribution drop me a line, 'cause I am always curious about that...
 
-=head1 CVS REVISION
-
-$Id: Admin.pm,v 1.37 2002/02/01 22:46:57 eric Exp $
-
 =head1 AUTHOR
 
 Eric Estabrooks, eric@urbanrage.com
